# GAM

The basics of fitting a gam are we first create a [`GAM`][pymgcv.gam.GAM] object, which specifies the model structure. We can then fit the gam using [`gam`][pymgcv.gam.GAM.fit], which returns a [`FittedGAM`][pymgcv.gam.FittedGAM] object.

::: pymgcv.gam.GAM
::: pymgcv.gam.FittedGAM
